==> production-inv-provider-0.0.2.38-sources.jar: com/elitesland/yst/production/inv/application/out/SystemServiceImpl.java <==
package com.elitesland.yst.production.inv.application.out;

import com.alibaba.excel.util.CollectionUtils;
import com.elitescloud.boot.auth.util.SecurityContextUtil;
import com.elitescloud.cloudt.common.base.ApiCode;
import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitescloud.boot.exception.BusinessException;
import com.elitescloud.boot.core.base.SeqNumProvider;
import com.elitescloud.boot.core.base.UdcProvider;
import com.elitescloud.cloudt.security.entity.GeneralUserDetails;
import com.elitescloud.cloudt.system.dto.req.SysAreaQueryDTO;
import com.elitescloud.cloudt.system.dto.resp.SysAreaRespDTO;
import com.elitescloud.cloudt.system.provider.SysUserRpcService;
import com.elitescloud.cloudt.system.provider.extend.SysAreaRpcService;
import com.elitescloud.cloudt.system.service.*;
import com.elitescloud.cloudt.system.vo.SysSettingVO;
import com.elitesland.yst.production.inv.Application;
import com.elitescloud.cloudt.system.param.SysUserIdFlowRoleRpcParam;
import com.elitescloud.cloudt.system.vo.SysUserDTO;
import com.elitescloud.cloudt.system.vo.SysUserVO;
import com.elitesland.yst.production.support.provider.item.service.ItmItemRpcService;
import com.google.common.collect.Lists;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.*;

@Service
@AllArgsConstructor
@Slf4j
public class SystemServiceImpl implements SystemService {
    /**
     * 发号器
     */
    private final SeqNumProvider sysNumberRuleService;
    private final SysUserFlowRoleRpcService sysUserFlowRoleRpcService;
    private final UdcProvider udcProvider;
//    private final ComCityCodeRpcService comCityCodeRpcService;
    private final SysAreaRpcService sysAreaRpcService;
    private final ItmItemRpcService itemRpcService;
    private final SysUserRpcService sysUserService;

    private final SysSettingService sysSettingService;



    @Override
    public Map<String, String> sysUdcGetCodeMap(String domain, String udc) {
        try {
            Map<String, String> codeMap = udcProvider.getValueMapByUdcCode(domain, udc);
            return codeMap ;
        } catch (Exception e) {
            log.error("findCodeBatch error:", e);
        }
        return new HashMap<>();
    }

    /**
     * 发号器发号
     * @param code
     * @param runtimeValues
     * @return
     */
    @Override
    public String sysNumberRuleGenerateCode(String code, List<String> runtimeValues) {
        log.info("库存中心发号器调用：时间：{}，参数{},{}", LocalDateTime.now(),code,runtimeValues);
        String sys ="";
        List<String> list = new ArrayList<>();
        list.addAll(runtimeValues);
        try {
            sys =sysNumberRuleService.generateCode(Application.NAME,code, list);
        } catch (Exception e) {
            log.error("sysNumberRuleGenerateCode error:", e);
            throw new BusinessException(ApiCode.BUSINESS_EXCEPTION, "发号器发号失败");
        }
        return sys;
    }

    /**
     * 商品库存参数配置模块 - 更据计划员工ID查询系统用户账号信息
     *
     * @param calcEmpIds userids
     * @return 系统用户集
     */
    @Override
    public List<SysUserVO> findAllEmpsByIdIn(List<Long> calcEmpIds) {
        try {
            if (calcEmpIds.isEmpty()) {
                return null;
            }
            List<SysUserVO> sysUserVOList = sysUserService.getByIds(calcEmpIds);
            if (!CollectionUtils.isEmpty(sysUserVOList)) {
                return sysUserVOList;
            }
        } catch (Exception e) {
            log.error("findAllEmpsByIdIn error:", e);
        }
        return Lists.newArrayList();
    }

    @Override
    public List<Long> findUserIdsByFlowRoles(Long ouId, String customParams) {
        log.info("通过ouId,自定义参数获取用户列表，时间：{}，入参：{}", LocalDateTime.now(), ouId);
        try {
            SysUserIdFlowRoleRpcParam param =new SysUserIdFlowRoleRpcParam();
            param.setOuIds(Collections.singletonList(ouId));
            param.setFlowRoleCodes(Collections.singletonList(customParams));
            List<Long> userIds = sysUserFlowRoleRpcService.findUserIdsByFlowRoles(param);
            if (!org.springframework.util.CollectionUtils.isEmpty(userIds)) {
                return userIds;
            }
        } catch (Exception e) {
            log.error("findUserIdsByFlowRoles error:", e);
            throw new BusinessException( ApiCode.FAIL, e.getMessage());
        }
        return null;
    }

    @Override
    public SysUserDTO sysUserCurrent() {
        try {
            GeneralUserDetails userDetails = SecurityContextUtil.currentUser();;
            if (userDetails == null) {
                return null;
            }
            SysUserDTO sysUserDTO = userDetails.getUser();
            if (sysUserDTO == null) {
                return null;
            }
            return sysUserDTO;
        } catch (Exception e) {
            log.error("sysUserCurrent error:", e);
        }
        return null;
    }

    /**
     * 根获取区域信息列表
     *
     * @param param 入参
     * @return 区域集
     */
    @Override
    public List<SysAreaRespDTO> findAreaByParam(List<String> areaCodes) {
        log.info("调用系统域-获取区域信息列表，时间：{}，入参：{}", LocalDateTime.now(), areaCodes);
        try {
            Set<String> set=new HashSet<>(areaCodes);
            SysAreaQueryDTO sysAreaQueryDTO = new SysAreaQueryDTO();
            sysAreaQueryDTO.setAreaCodes(set);
            ApiResult<List<SysAreaRespDTO>> apiResult = sysAreaRpcService.queryList(sysAreaQueryDTO);
            return apiResult.getData();
        } catch (Exception e) {
            log.error("findAreaByCodes error:", e);
        }
        return Collections.EMPTY_LIST;

    }

    @Override
    public SysSettingVO findSysSetting(String settingNo){
        log.info("调用系统域-获取系统配置参数，时间：{}，入参：{}", LocalDateTime.now(), settingNo);
        try {
            SysSettingVO sysSettingVO = sysSettingService.oneByNo(settingNo);
            return sysSettingVO;
        } catch (Exception e){
            throw new BusinessException("调用系统域-获取系统配置参数服务失败",e);
        }
    }
}

==> production-inv-provider-0.0.2.89-sources.jar: com/elitesland/yst/production/inv/application/out/SystemServiceImpl.java <==
package com.elitesland.yst.production.inv.application.out;

import cn.hutool.core.collection.CollectionUtil;
import com.alibaba.excel.util.CollectionUtils;
import com.elitescloud.boot.auth.util.SecurityContextUtil;
import com.elitescloud.cloudt.common.base.ApiCode;
import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitescloud.boot.exception.BusinessException;
import com.elitescloud.boot.core.base.SeqNumProvider;
import com.elitescloud.boot.core.base.UdcProvider;
import com.elitescloud.cloudt.security.entity.GeneralUserDetails;
import com.elitescloud.cloudt.system.dto.SysOrgBasicDTO;
import com.elitescloud.cloudt.system.dto.req.SysAreaQueryDTO;
import com.elitescloud.cloudt.system.dto.resp.SysAreaRespDTO;
import com.elitescloud.cloudt.system.provider.SysUserRpcService;
import com.elitescloud.cloudt.system.provider.extend.SysAreaRpcService;
import com.elitescloud.cloudt.system.provider.org.OrgRpcService;
import com.elitescloud.cloudt.system.service.*;
import com.elitescloud.cloudt.system.vo.SysSettingVO;
import com.elitesland.yst.production.inv.Application;
import com.elitescloud.cloudt.system.param.SysUserIdFlowRoleRpcParam;
import com.elitescloud.cloudt.system.vo.SysUserDTO;
import com.elitescloud.cloudt.system.vo.SysUserVO;
import com.elitesland.yst.production.support.provider.item.service.ItmItemRpcService;
import com.google.common.collect.Lists;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.*;

@Service
@AllArgsConstructor
@Slf4j
public class SystemServiceImpl implements SystemService {
    /**
     * 发号器
     */
    private final SeqNumProvider sysNumberRuleService;
    private final SysUserFlowRoleRpcService sysUserFlowRoleRpcService;
    private final UdcProvider udcProvider;
//    private final ComCityCodeRpcService comCityCodeRpcService;
    private final SysAreaRpcService sysAreaRpcService;
    private final ItmItemRpcService itemRpcService;
    private final SysUserRpcService sysUserService;

    private final SysSettingService sysSettingService;
    private final OrgRpcService orgRpcService;



    @Override
    public Map<String, String> sysUdcGetCodeMap(String domain, String udc) {
        try {
            Map<String, String> codeMap = udcProvider.getValueMapByUdcCode(domain, udc);
            return codeMap ;
        } catch (Exception e) {
            log.error("findCodeBatch error:", e);
        }
        return new HashMap<>();
    }

    /**
     * 发号器发号
     * @param code
     * @param runtimeValues
     * @return
     */
    @Override
    public String sysNumberRuleGenerateCode(String code, List<String> runtimeValues) {
        log.info("库存中心发号器调用：时间：{}，参数{},{}", LocalDateTime.now(),code,runtimeValues);
        String sys ="";
        List<String> list = new ArrayList<>();
        list.addAll(runtimeValues);
        try {
            sys =sysNumberRuleService.generateCode(Application.NAME,code, list);
        } catch (Exception e) {
            log.error("sysNumberRuleGenerateCode error:", e);
            throw new BusinessException(ApiCode.BUSINESS_EXCEPTION, "发号器发号失败");
        }
        return sys;
    }

    /**
     * 商品库存参数配置模块 - 更据计划员工ID查询系统用户账号信息
     *
     * @param calcEmpIds userids
     * @return 系统用户集
     */
    @Override
    public List<SysUserVO> findAllEmpsByIdIn(List<Long> calcEmpIds) {
        try {
            if (calcEmpIds.isEmpty()) {
                return null;
            }
            List<SysUserVO> sysUserVOList = sysUserService.getByIds(calcEmpIds);
            if (!CollectionUtils.isEmpty(sysUserVOList)) {
                return sysUserVOList;
            }
        } catch (Exception e) {
            log.error("findAllEmpsByIdIn error:", e);
        }
        return Lists.newArrayList();
    }

    @Override
    public List<Long> findUserIdsByFlowRoles(Long ouId, String customParams) {
        log.info("通过ouId,自定义参数获取用户列表，时间：{}，入参：{}", LocalDateTime.now(), ouId);
        try {
            SysUserIdFlowRoleRpcParam param =new SysUserIdFlowRoleRpcParam();
            param.setOuIds(Collections.singletonList(ouId));
            param.setFlowRoleCodes(Collections.singletonList(customParams));
            List<Long> userIds = sysUserFlowRoleRpcService.findUserIdsByFlowRoles(param);
            if (!org.springframework.util.CollectionUtils.isEmpty(userIds)) {
                return userIds;
            }
        } catch (Exception e) {
            log.error("findUserIdsByFlowRoles error:", e);
            throw new BusinessException( ApiCode.FAIL, e.getMessage());
        }
        return null;
    }

    @Override
    public SysUserDTO sysUserCurrent() {
        try {
            GeneralUserDetails userDetails = SecurityContextUtil.currentUser();;
            if (userDetails == null) {
                return null;
            }
            SysUserDTO sysUserDTO = userDetails.getUser();
            if (sysUserDTO == null) {
                return null;
            }
            return sysUserDTO;
        } catch (Exception e) {
            log.error("sysUserCurrent error:", e);
        }
        return null;
    }

    /**
     * 根获取区域信息列表
     *
     * @param param 入参
     * @return 区域集
     */
    @Override
    public List<SysAreaRespDTO> findAreaByParam(List<String> areaCodes) {
        log.info("调用系统域-获取区域信息列表，时间：{}，入参：{}", LocalDateTime.now(), areaCodes);
        try {
            Set<String> set=new HashSet<>(areaCodes);
            SysAreaQueryDTO sysAreaQueryDTO = new SysAreaQueryDTO();
            sysAreaQueryDTO.setAreaCodes(set);
            ApiResult<List<SysAreaRespDTO>> apiResult = sysAreaRpcService.queryList(sysAreaQueryDTO);
            return apiResult.getData();
        } catch (Exception e) {
            log.error("findAreaByCodes error:", e);
        }
        return Collections.EMPTY_LIST;

    }

    @Override
    public SysSettingVO findSysSetting(String settingNo){
        log.info("调用系统域-获取系统配置参数，时间：{}，入参：{}", LocalDateTime.now(), settingNo);
        try {
            SysSettingVO sysSettingVO = sysSettingService.oneByNo(settingNo);
            return sysSettingVO;
        } catch (Exception e){
            throw new BusinessException("调用系统域-获取系统配置参数服务失败",e);
        }
    }


    /**
     * 根据编码获取上级组织信息
     *
     * @param codes 组织编码
     * @param parentType 上级类型
     * @return
     */
    @Override
    public Map<String, SysOrgBasicDTO> getParentByCodeAndParentType(Set<String> codes, String parentType) {
        //log.info("调用系统域(getParentByCode)根据编码获取上级组织信息接口，时间：{}，入参：{}", LocalDateTime.now(), JSON.toJSONString(codes));
        if (CollectionUtil.isEmpty(codes)) {
            return new HashMap<>();
        }
        try {
            ApiResult< Map<String, SysOrgBasicDTO>> apiResult = orgRpcService.getParentByCode(codes,parentType);
            //log.info("调用系统域-getParentByCode，时间：{}，出参：{}", LocalDateTime.now(), JSON.toJSONString(apiResult));
            if (apiResult.isSuccess()) {
                Map<String, SysOrgBasicDTO> orgBasicDTOMap = apiResult.getData();
                return orgBasicDTOMap;
            } else {
                throw new BusinessException(ApiCode.FAIL, "调用系统域(getParentByCode)根据编码获取上级组织信息失败：" + apiResult.getMsg());
            }
        } catch (Exception e) {
            log.error("getParentByCodeAndParentType error:", e);
            throw new BusinessException(ApiCode.FAIL, "调用系统中心dubbo服务异常：" + e);
        }

        //return null;
    }


}
